import { NATIVE } from '../wrapper';
import { convertToSentryProfile } from './convertHermesProfile';
/**
 * Hermes Profile Stack Frame Name contains function name and file path.
 *
 * `foo(/path/to/file.js:1:2)` -> `foo`
 */
export function parseHermesStackFrameFunctionName(hermesName) {
    const indexOfLeftParenthesis = hermesName.indexOf('(');
    const name = indexOfLeftParenthesis !== -1 ? hermesName.substring(0, indexOfLeftParenthesis) : hermesName;
    return name;
}
const MS_TO_NS = 1e6;
/**
 * Starts Hermes Sampling Profiler and returns the timestamp when profiling started in nanoseconds.
 */
export function startProfiling() {
    const started = NATIVE.startProfiling();
    if (!started) {
        return null;
    }
    const profileStartTimestampNs = Date.now() * MS_TO_NS;
    return profileStartTimestampNs;
}
/**
 * Stops Hermes Sampling Profiler and returns the profile.
 */
export function stopProfiling() {
    const hermesProfile = NATIVE.stopProfiling();
    if (!hermesProfile) {
        return null;
    }
    return convertToSentryProfile(hermesProfile);
}
//# sourceMappingURL=hermes.js.map